/*
** File: dmabus.c  
** Project: ADMXRC3 API module library
** Purpose: OS-independent code for ADMXRC3 API module library
**
** (C) Copyright Alpha Data 2009-2011
**
** Implements the ADMXRC3_*DMABus functions.
*/

#include <admxrc3/dmabus.h>
#include <admxrc3_platform.h>
#include <portable_file.h>
#include <portable_string.h>
#if PORTABLE_HAS_WCHAR_SUPPORT
# include <portable_wstring.h>
#endif
#include "ioctl_admxrc3.h"

ADMXRC3_EXPORT ADMXRC3_STATUS
ADMXRC3_CALLING_CONVENTION
ADMXRC3_ReadDMABus(
  ADMXRC3_HANDLE hCard,
  unsigned int dmaChannel,
  uint32_t flags,
  uint64_t busAddress,
  size_t length,
  uint64_t localAddress)
{
  IOCTLS_ADMXRC3_READDMABUS ioctl;

  ioctl.in.channel = dmaChannel;
  ioctl.in.flags = flags;
  ioctl.in.bus = busAddress;
  ioctl.in.length = length;
  ioctl.in.local = localAddress;
  return admxrc3Ioctl(hCard, ADMXRC3_IOCTLCODE_READDMABUS, &ioctl, sizeof(ioctl.in), 0);
}

ADMXRC3_EXPORT ADMXRC3_STATUS
ADMXRC3_CALLING_CONVENTION
ADMXRC3_StartReadDMABus(
  ADMXRC3_HANDLE hCard,
  ADMXRC3_TICKET* pTicket,
  unsigned int dmaChannel,
  uint32_t flags,
  uint64_t busAddress,
  size_t length,
  uint64_t localAddress)
{
  IOCTLS_ADMXRC3_READDMABUS ioctl;

  ioctl.in.channel = dmaChannel;
  ioctl.in.flags = flags;
  ioctl.in.bus = busAddress;
  ioctl.in.length = length;
  ioctl.in.local = localAddress;
  return admxrc3IoctlNonBlock(hCard, pTicket, ADMXRC3_IOCTLCODE_READDMABUS, &ioctl, sizeof(ioctl.in), 0);
}

ADMXRC3_EXPORT ADMXRC3_STATUS
ADMXRC3_CALLING_CONVENTION
ADMXRC3_WriteDMABus(
  ADMXRC3_HANDLE hCard,
  unsigned int dmaChannel,
  uint32_t flags,
  uint64_t busAddress,
  size_t length,
  uint64_t localAddress)
{
  IOCTLS_ADMXRC3_WRITEDMABUS ioctl;

  ioctl.in.channel = dmaChannel;
  ioctl.in.flags = flags;
  ioctl.in.bus = busAddress;
  ioctl.in.length = length;
  ioctl.in.local = localAddress;
  return admxrc3Ioctl(hCard, ADMXRC3_IOCTLCODE_WRITEDMABUS, &ioctl, sizeof(ioctl.in), 0);
}

ADMXRC3_EXPORT ADMXRC3_STATUS
ADMXRC3_CALLING_CONVENTION
ADMXRC3_StartWriteDMABus(
  ADMXRC3_HANDLE hCard,
  ADMXRC3_TICKET* pTicket,
  unsigned int dmaChannel,
  uint32_t flags,
  uint64_t busAddress,
  size_t length,
  uint64_t localAddress)
{
  IOCTLS_ADMXRC3_WRITEDMABUS ioctl;

  ioctl.in.channel = dmaChannel;
  ioctl.in.flags = flags;
  ioctl.in.bus = busAddress;
  ioctl.in.length = length;
  ioctl.in.local = localAddress;
  return admxrc3IoctlNonBlock(hCard, pTicket, ADMXRC3_IOCTLCODE_WRITEDMABUS, &ioctl, sizeof(ioctl.in), 0);
}
