#ifndef _ADATA_API_ADMXRC3_PLATFORM_H
#define _ADATA_API_ADMXRC3_PLATFORM_H

/*
** File: admxrc3_platform.h  
** Project: ADMXRC3 API module library
** Purpose: Interface to VxWorks-specific functions for ADMXRC3 API module library
**
** (C) Copyright Alpha Data 2009-2011
*/

#include <vxWorks.h>
#include <semLib.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>

#include <portability.h>

#include <admxrc3/platform.h>
#include <admxrc3/status.h>
#include <admxrc3/types.h>
#include <admxrc3/ticket.h>

#define ADMXRC3_HAS_USER_EVENT_HANDLE PORTABLE_HAS_USER_EVENT_HANDLE
typedef portable_user_event_handle_t admxrc3_user_event_handle_t;

extern ADMXRC3_STATUS
admxrc3OpenDevice(
  unsigned int index,
  int bUnprivileged,
  ADMXRC3_HANDLE* phDevice);

extern ADMXRC3_STATUS
admxrc3CloseDevice(
  ADMXRC3_HANDLE hDevice);

extern ADMXRC3_STATUS
admxrc3Ioctl(
  ADMXRC3_HANDLE hDevice,
  unsigned int code,
  void* pIoctl,
  unsigned int sizeIn,
  unsigned int sizeOut);

extern ADMXRC3_STATUS
admxrc3IoctlNonBlock(
  ADMXRC3_HANDLE hDevice,
  ADMXRC3_TICKET* pTicket,
  unsigned int code,
  void* pIoctl,
  unsigned int sizeIn,
  unsigned int sizeOut);

ADMXRC3_STATUS
admxrc3FinishNonBlock(
  ADMXRC3_HANDLE hAdmxrc3,
  ADMXRC3_TICKET* pTicket,
  bool_t bWait,
  void* pIoctl,
  unsigned int sizeOut);

extern ADMXRC3_STATUS
admxrc3IoctlCancel(
  ADMXRC3_HANDLE hDevice);

extern ADMXRC3_STATUS
admxrc3MapRegion(
  ADMXRC3_HANDLE hCard,
  unsigned int windowIndex,
  uint64_t offset,
  uint64_t length,
  void** ppVirtualBase);

extern ADMXRC3_STATUS
admxrc3UnmapRegion(
  ADMXRC3_HANDLE hCard,
  const void* pVirtualBase);

#if (_WRS_VXWORKS_MAJOR >= 6)
# define portableFormatStringA1(buf, max, format, arg1) snprintf(buf, max, format, arg1)
# define portableFormatStringA2(buf, max, format, arg1, arg2) snprintf(buf, max, format, arg1, arg2)
# define portableFormatStringA3(buf, max, format, arg1, arg2, arg3) snprintf(buf, max, format, arg1, arg2, arg3)
# define portableFormatStringA4(buf, max, format, arg1, arg2, arg3, arg4) snprintf(buf, max, format, arg1, arg2, arg3, arg4)
#else
  /* Need VxWorks 6.x for snprintf() */
# define portableFormatStringA1(buf, max, format, arg1) sprintf(buf, format, arg1)
# define portableFormatStringA2(buf, max, format, arg1, arg2) sprintf(buf, format, arg1, arg2)
# define portableFormatStringA3(buf, max, format, arg1, arg2, arg3) sprintf(buf, format, arg1, arg2, arg3)
# define portableFormatStringA4(buf, max, format, arg1, arg2, arg3, arg4) sprintf(buf, format, arg1, arg2, arg3, arg4)
#endif

#endif
